function [muS,muN,sigmaS,sigmaN] = latdist_unfilter(pos,ia)
% LATDIST_UNFILTER finds lateral distributions across defined  
% cross-sections and creates distribution histograms per vessel 
% 
%
% Inputs:
%   pos: Vessel position matrix
%   ia:  vessel indexes in position matrix
%
% Outputs:
%   muS:    Southbound mean position mu
%   muN:    Northbound mean position mu
%   sigmaS: Southbound standard deviation sigma
%   sigmaN: Northbound standard deviation sigma
%


ID = pos(:,1);  % Vessel ID
long = pos(:,2);% Longitude
lat = pos(:,3); % Latitude
n_v = length(ia); % n vessels
n_m = length(pos); % n messages


%Cross-section coordinates
%Vanylvsfjorden
%H1=[5.3880,62.093];
%H2=[5.4327,62.1112];
%Gamla lysbye-Furuneset
H1=[5.092,62.0963];
H2=[5.109,62.0963];
%Passline A- 10 km
%H1=[4.9512533,62.24927];
%H2=[5.09843,62.19222];
%Passline A - short
%H1= [5.0804108,62.1992205];
%H2= [5.0965404,62.1930597];
%-Trondheimsleia, Hitra-
%Snekkflua-Eitera
%H1=[8.7247,63.4524];
%H2=[8.7535,63.4246];

%Cross section line function
v = [(H2(2)-H1(2)),(H2(1)-H1(1))];
a = v(1)/v(2);
c = -a*(H1(1))+H1(2);

%Southbound passage--------------------------------------------------------
k=0; %n Crossings

for i = 1:n_v-1
    for j = ia(i):ia(i+1)-1
        if lat(j)>a*long(j)+c&&lat(j+1)<=a*long(j+1)+c&&ID(j)==ID(j+1)&&...
                long(j+1)>=H1(1)&&long(j+1)<=H2(1)
            k = k+1;
            V1(k,:) = [long(j),lat(j)];
            V2(k,:) = [long(j+1),lat(j+1)];
            vV(k,:) = [(V2(k,2)-V1(k,2)),(V2(k,1)-V1(k,1))];
            b(k) = vV(k,1)/vV(k,2);
            d(k) = -b(k)*(V1(k,1))+V1(k,2);
            S(k,:) = [(d(k)-c)/(a-b(k)),(a*d(k)-b(k)*c)/(a-b(k))];
        end
    end
end

% Separate loop for last vessel
for j = ia(n_v):length(pos)-1
    if lat(j)>a*long(j)+c&&lat(j+1)<=a*long(j+1)+c&&ID(j)==ID(j+1)&&...
            long(j+1)>=H1(1)&&long(j+1)<=H2(1)
        k=k+1;
        V1(k,:) = [long(j),lat(j)];
        V2(k,:) = [long(j+1),lat(j+1)];
        vV(k,:) = [(V2(k,2)-V1(k,2)),(V2(k,1)-V1(k,1))];
        b(k) = vV(k,1)/vV(i,2);
        d(k) = -b(k)*(V1(k,1))+V1(k,2);
        S(k,:) = [(d(k)-c)/(a-b(k)),(a*d(k)-b(k)*c)/(a-b(k))];
    end
end

s1 = nonzeros(S(:,1));
s2 = nonzeros(S(:,2));
S1(:,1) = s1;
S1(:,2) = s2;

% Intersect distances from start point of histogram line. Start points is
% lowest longitude.

VS = [S1(:,2)-H1(2),S1(:,1)-H1(1)];
VSabs = sqrt((VS(:,1)).^2+(VS(:,2).^2));
vabs = sqrt((v(1)).^2+(v(2)).^2);
SRatio = VSabs/vabs;

B = SRatio>1;
b = find(B);
SRatio(b) = [];

% Northbound passages------------------------------------------------------
k2 = 0;
for i = 1:n_v-1
    for j = ia(i):ia(i+1)-1
        if lat(j)<a*long(j)+c&&lat(j+1)>=a*long(j+1)+c&&ID(j)==ID(j+1)&&...
                long(j+1)>=H1(1)&&long(j+1)<=H2(1)
            k2 = k2+1;
            V1(k2,:) = [long(j),lat(j)];
            V2(k2,:) = [long(j+1),lat(j+1)];
            vV(k2,:) = [(V2(k2,2)-V1(k2,2)),(V2(k2,1)-V1(k2,1))];
            b(k2) = vV(k2,1)/vV(k2,2);
            d(k2) = -b(k2)*(V1(k2,1))+V1(k2,2);
            N(k2,:) = [(d(k2)-c)/(a-b(k2)),(a*d(k2)-b(k2)*c)/(a-b(k2))];
        end
    end
end

% Separate loop for last vessel
for j = ia(n_v):length(pos)-1
    if lat(j)<a*long(j)+c&&lat(j+1)>=a*long(j+1)+c&&ID(j)==ID(j+1)&&...
                long(j+1)>=H1(1)&&long(j+1)<=H2(1)
        k2=k2+1;
        V1(k2,:) = [long(j-1),lat(j-1)];
        V2(k2,:) = [long(j),lat(j)];
        vV(k2,:) = [(V2(k2,2)-V1(k2,2)),(V2(k2,1)-V1(k2,1))];
        b(k2) = vV(k2,1)/vV(k2,2);
        d(k2) = -b(k2)*(V1(k2,1))+V1(k2,2);
        N(k2,:) = [(d(k2)-c)/(a-b(k2)),(a*d(k2)-b(k2)*c)/(a-b(k2))];
    end
end

n1 = nonzeros(N(:,1));
n2 = nonzeros(N(:,2));
N1(:,1) = n1;
N1(:,2) = n2;

% Intersect distances from start point of histogram line. Start point is
% lowest longitude

VN = [N1(:,2)-H1(2),N1(:,1)-H1(1)];
VNabs = sqrt((VN(:,1)).^2+(VN(:,2).^2));
vabs = sqrt((v(1)).^2+(v(2)).^2);
NRatio = VNabs/vabs;

B = NRatio>1;
b = find(B);
NRatio(b) = [];

% Plot histograms of lateral distribution----------------------------------
pdN = fitdist(NRatio,'normal');
pdS = fitdist(SRatio,'normal');
muN = pdN.mu; 
muS = pdS.mu; 
sigmaN = pdN.sigma; 
sigmaS = pdS.sigma; 

figure(1)
subplot(1,2,1), histfit(SRatio,40,'normal');
xlim([0 1])
ylabel('n vessels')
xlabel('section of fairway width')
title('Southbound distribution')
subplot(1,2,2),histfit(NRatio,40,'normal')
xlim([0 1])
ylabel('n vessels')
xlabel('section of fairway width')
title('Northbound distribution')
end