% tsvread_parameters
%Reads data including lat, long, MMSI,
%breadth, length, draught and SOG from .tsv format
% Outputs:
%   pos:position matrix
%   ia: vessel index in position matrix
%   vType:List of observed vessel types

FileID=dir('*.tsv');%All .tsv files in directory
N = {FileID.name};
N1=char(N);
n=length(N);

Data = tdfread(N1(1,:));
fields = fieldnames(Data); 
Struct(1).MMSI = Data.MMSI;
Struct(1).Lat = Data.Decimal_Latitude;
Struct(1).Long = Data.Decimal_Longitude;
Struct(1).Type = Data.Ship_type;
Struct(1).Breadth = Data.Breadth;
Struct(1).Length = Data.Length;
Struct(1).Draught = Data.Maximum_actual_draught;
Struct(1).SOG=Data.SOG;

%The following code is for catenating several tsv data files into one
%matrix. Note that the  procedure causes first message of every TSV file 
%to be lost. This should be negligible.
    
if n>=2
   for i = 2:n
        Data = tdfread(N1(i,:));
        %Find and save imported field names
        oldFields = fieldnames(Data);    
        Breadthfield = char(oldFields(1,:));
        Lengthfield = char(oldFields(2,:));
        MMSIfield = char(oldFields(3,:));
        Draughtfield = char(oldFields(4,:));
        Typefield = char(oldFields(5,:));
        Latfield = char(oldFields(6,:));
        Longfield = char(oldFields(7,:));
        sogfield = char(oldFields(8,:));
        %Create new fields with correct names
        [Data.Breadth] = Data.(Breadthfield);
        [Data.Length] = Data.(Lengthfield);
        [Data.MMSI] = Data.(MMSIfield);
        [Data.Draught]=Data.(Draughtfield);
        [Data.Type] = Data.(Typefield);
        [Data.Lat] = Data.(Latfield);
        [Data.Long] = Data.(Longfield);
        [Data.SOG] = Data.(sogfield);
        %Remove old fields 
        Data = rmfield(Data,Breadthfield);
        Data = rmfield(Data,Lengthfield);
        Data = rmfield(Data,MMSIfield);
        Data = rmfield(Data,Typefield);
        Data = rmfield(Data,Latfield);
        Data = rmfield(Data,Longfield);
        Data = rmfield(Data,Draughtfield);
        Data = rmfield(Data,sogfield);
        %Create struct with correct field names
        Struct(i).Breadth = Data.Breadth;
        Struct(i).Length = Data.Length;
        Struct(i).MMSI = Data.MMSI;
        Struct(i).Draught = Data.Draught;
        Struct(i).Type = Data.Type;
        Struct(i).Lat = Data.Lat;
        Struct(i).Long = Data.Long;
        Struct(i).SOG = Data.SOG;
    end
end


%Create vectors for MMSI, lat and long from struct arrays
%Preallocation not possible here
Breadth=[];
Length=[];
MMSI=[];
Draught=[];
Type=[];
lat=[];
long=[];
SOG=[];
 
for i = 1:n
    Breadth = [Breadth;Struct(i).Breadth];
    Length = [Length;Struct(i).Length];
    MMSI = [MMSI;Struct(i).MMSI];
    Draught = [Draught;Struct(i).Draught];
    Type = [Type;Struct(i).Type];
    lat = [lat;Struct(i).Lat];
    long = [long;Struct(i).Long];
    SOG = [SOG;Struct(i).SOG];
    
end

%Find index vector ic to number MMSIs in order of appearance
[vID,ia,ic] = unique(MMSI,'rows','stable');

pos=zeros(length(ic),6);
pos(:,1) = ic; %ID number in order of appearance
pos(:,2) = long;
pos(:,3) = lat;
pos(:,4) = Breadth;
pos(:,5) = Length;
[vType,via,vic] = unique(Type,'rows','stable');
pos(:,6) = vic;
pos(:,7) = Draught;
pos(:,8) = SOG;
pos = sortrows(pos,1);

%Find indexes vector of first appeareance of unique MMSI in sorted pos 
%matrix, ia
[vIDn,ia,ic2] = unique(pos(:,1),'rows','stable');



