%Ship type and dimension statistics
function [Vstats,Stats,vType]=vesselstats(vType,pos,ki,ia,kae)
% VESSELSTATS
%
% Inputs:
%   vType:List of observed vessel types
%   pos: Vessel position matrix
%   ki: index of relevant vessels
%   ia: index of relevant pos matrix entries
%   kae: Passline matrix
%
% Outputs:
%   Vstats:Vessel parameters for each vessel
%   Stats:Vessel parameters 
%   vType:Reordered list of vessel types


ncats = size(vType); %Vessel categories
ncats = ncats(1);
Vstats = zeros(length(ki),5);
Typecount=zeros(ncats,1);

for i =1:length(kae)
    if kae(i,1)>0
        Vstats(i,1)=pos(ia(ki(i)),6); %Type
        Typecount(Vstats(i,1))=Typecount(Vstats(i,1))+kae(i,1);
        Vstats(i,2)=pos(ia(ki(i)),4); %Breadth
        Vstats(i,3)=pos(ia(ki(i)),5); %Length
        Vstats(i,4)=pos(ia(ki(i)),7); %Draught
        Vstats(i,5)=pos(ia(ki(i)),8); %SOG
    end
end


Bmat=zeros(length(Vstats),ncats); 
Lmat=Bmat;
Dmat=Bmat;
Smat=Bmat;

for i = 1:length(Vstats)
    for j = 1:ncats
       if Vstats(i,1)==j
          Bmat(i,j)=Vstats(i,2);
          Lmat(i,j)=Vstats(i,3);
          Dmat(i,j)=Vstats(i,4);
          Smat(i,j)=Vstats(i,5);
       end
    end
end

%Average dimensions vectors
for i = 1:ncats
    Bavg(i,1)=sum(Bmat(:,i))/nnz(Bmat(:,i));
    Lavg(i,1)=sum(Lmat(:,i))/nnz(Lmat(:,i));
    Davg(i,1)=sum(Dmat(:,i))/nnz(Dmat(:,i));
    if nnz(Smat(:,i))>0
        Savg(i,1)=sum(Smat(:,i))/nnz(Smat(:,i));
    else
        Savg(i,1)=0;
    end
end

%avg vessel type parameters matrix
Stats(:,1) = Typecount;
Stats(:,2) = Bavg;
Stats(:,3) = Lavg;
Stats(:,4) = Davg;
Stats(:,5) = Savg;

%Filter out zero entries - vessels that don't cross specified lines
nrows=Stats(:,1)==0;
Stats(nrows,:)=[];
vType(nrows,:)=[];
nrows=Stats(:,5)==0;
Stats(nrows,:)=[];
vType(nrows,:)=[];
%Concentrate misc vessel types into 1 category
zrows=Stats(:,1)<=5;
Statsk=Stats;
Statsk(zrows,:)=[];
vType(zrows,:)=[];
if nnz(zrows)>1
    Statsk(length(Statsk)+1,:)=[sum(Stats(zrows,1)) mean(Stats(zrows,2:5))];
elseif nnz(zrows)==1
    Statsk(length(Statsk)+1,:)=[sum(Stats(zrows,1)) (Stats(zrows,2:5))];
end
Stats=Statsk;
vType(length(Statsk),:)='Misc                                                 ';

end
